git.vger.kernel.org archive mirror
 help / color / mirror / Atom feed
From: Sergey Organov <sorganov@gmail.com>
To: Junio C Hamano <gitster@pobox.com>
Cc: "Jeff King" <peff@peff.net>,
	"Philip Oakley" <philipoakley@iee.email>,
	"Elijah Newren" <newren@gmail.com>,
	"Felipe Contreras" <felipe.contreras@gmail.com>,
	"Ævar Arnfjörð Bjarmason" <avarab@gmail.com>,
	git@vger.kernel.org, "Sergey Organov" <sorganov@gmail.com>
Subject: [PATCH v2 3/5] diff-merges: adapt -m to enable default diff format
Date: Tue, 13 Apr 2021 14:41:16 +0300	[thread overview]
Message-ID: <20210413114118.25693-4-sorganov@gmail.com> (raw)
In-Reply-To: <20210413114118.25693-1-sorganov@gmail.com>

Let -m option (and --diff-merges=m) enable the default format instead
of "separate", to be able to tune it with log.diffMerges option.

Signed-off-by: Sergey Organov <sorganov@gmail.com>
---
 diff-merges.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/diff-merges.c b/diff-merges.c
index 66c8ba0cc6a0..9d19225b3ec9 100644
--- a/diff-merges.c
+++ b/diff-merges.c
@@ -34,10 +34,10 @@ static void set_m(struct rev_info *revs)
 {
 	/*
 	 * To "diff-index", "-m" means "match missing", and to the "log"
 	 * family of commands, it means "show full diff for merges". Set
 	 * both fields appropriately.
 	 */
-	set_separate(revs);
+	set_to_default(revs);
 	revs->match_missing = 1;
 }
 
@@ -61,13 +61,13 @@ static diff_merges_setup_func_t func_by_opt(const char *optarg)
 		return suppress;
 	if (!strcmp(optarg, "1") || !strcmp(optarg, "first-parent"))
 		return set_first_parent;
-	else if (!strcmp(optarg, "m") || !strcmp(optarg, "separate"))
+	else if (!strcmp(optarg, "separate"))
 		return set_separate;
 	else if (!strcmp(optarg, "c") || !strcmp(optarg, "combined"))
 		return set_combined;
 	else if (!strcmp(optarg, "cc") || !strcmp(optarg, "dense-combined"))
 		return set_dense_combined;
-	else if (!strcmp(optarg, "on"))
+	else if (!strcmp(optarg, "m") || !strcmp(optarg, "on"))
 		return set_to_default;
 	return NULL;
 }
@@ -34,10 +34,10 @@ static void set_m(struct rev_info *revs)
 	/*
 	 * To "diff-index", "-m" means "match missing", and to the "log"
-	 * family of commands, it means "show full diff for merges". Set
+	 * family of commands, it means "show default diff for merges". Set
 	 * both fields appropriately.
 	 */
-- 
2.25.1


  parent reply	other threads:[~2021-04-13 11:41 UTC|newest]

Thread overview: 47+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2021-04-07 22:55 [PATCH 0/9] git log: configurable default format for merge diffs Sergey Organov
2021-04-07 22:56 ` [PATCH 1/9] diff-merges: introduce --diff-merges=def Sergey Organov
2021-04-08 11:48   ` Philip Oakley
2021-04-08 14:21     ` Sergey Organov
2021-04-08 17:27       ` Junio C Hamano
2021-04-08 17:38         ` Sergey Organov
2021-04-07 22:56 ` [PATCH 2/9] diff-merges: refactor set_diff_merges() Sergey Organov
2021-04-07 22:56 ` [PATCH 3/9] diff-merges: introduce log.diffMerges config variable Sergey Organov
2021-04-08 21:37   ` SZEDER Gábor
2021-04-08 21:51     ` SZEDER Gábor
2021-04-08 22:01       ` Junio C Hamano
2021-04-08 23:04       ` Sergey Organov
2021-04-07 22:56 ` [PATCH 4/9] diff-merges: adapt -m to enable default diff format Sergey Organov
2021-04-07 22:56 ` [PATCH 5/9] t4013: add test for --diff-merges=def Sergey Organov
2021-04-07 22:56 ` [PATCH 6/9] t4013: add tests for log.diffMerges config Sergey Organov
2021-04-07 23:06   ` Ævar Arnfjörð Bjarmason
2021-04-07 23:35     ` Junio C Hamano
2021-04-08 14:25     ` Sergey Organov
2021-04-07 22:56 ` [PATCH 7/9] t9902: fix completion tests for log.d* to match log.diffMerges Sergey Organov
2021-04-07 23:05   ` Ævar Arnfjörð Bjarmason
2021-04-08 14:41     ` Sergey Organov
2021-04-08 19:50       ` Ævar Arnfjörð Bjarmason
2021-04-08 20:26         ` Sergey Organov
2021-04-08 22:13           ` SZEDER Gábor
2021-04-08 23:07             ` Sergey Organov
2021-04-07 22:56 ` [PATCH 8/9] doc/diff-options: document new --diff-merges features Sergey Organov
2021-04-07 22:56 ` [PATCH 9/9] doc/config: document log.diffMerges Sergey Organov
2021-04-10 17:16 ` [PATCH v1 0/5] git log: configurable default format for merge diffs Sergey Organov
2021-04-10 17:16   ` [PATCH v1 1/5] diff-merges: introduce --diff-merges=default Sergey Organov
2021-04-10 17:16   ` [PATCH v1 2/5] diff-merges: refactor set_diff_merges() Sergey Organov
2021-04-10 17:16   ` [PATCH v1 3/5] diff-merges: adapt -m to enable default diff format Sergey Organov
2021-04-10 17:16   ` [PATCH v1 4/5] diff-merges: introduce log.diffMerges config variable Sergey Organov
2021-04-10 17:16   ` [PATCH v1 5/5] doc/diff-options: document new --diff-merges features Sergey Organov
2021-04-11 16:13   ` [PATCH v1 0/5] git log: configurable default format for merge diffs Junio C Hamano
2021-04-11 18:04     ` Sergey Organov
2021-04-11 19:02       ` Junio C Hamano
2021-04-11 20:38         ` Sergey Organov
2021-04-11 21:58         ` Sergey Organov
2021-04-13 11:41 ` [PATCH v2 " Sergey Organov
2021-04-13 11:41   ` [PATCH v2 1/5] diff-merges: introduce --diff-merges=on Sergey Organov
2021-04-13 23:18     ` Junio C Hamano
2021-04-13 11:41   ` [PATCH v2 2/5] diff-merges: refactor set_diff_merges() Sergey Organov
2021-04-13 11:41   ` Sergey Organov [this message]
2021-04-13 11:41   ` [PATCH v2 4/5] diff-merges: introduce log.diffMerges config variable Sergey Organov
2021-04-15 20:21     ` Junio C Hamano
2021-04-16  8:30       ` Sergey Organov
2021-04-13 11:41   ` [PATCH v2 5/5] doc/diff-options: document new --diff-merges features Sergey Organov

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20210413114118.25693-4-sorganov@gmail.com \
    --to=sorganov@gmail.com \
    --cc=avarab@gmail.com \
    --cc=felipe.contreras@gmail.com \
    --cc=git@vger.kernel.org \
    --cc=gitster@pobox.com \
    --cc=newren@gmail.com \
    --cc=peff@peff.net \
    --cc=philipoakley@iee.email \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).